import re

import xbmc

from resources.lib.const import URL, SETTINGS, lang_to_iso_3
import xmlrpclib

from resources.lib.storage.settings import settings


class OpenSubtitles:
    def __init__(self):
        self.server = xmlrpclib.Server(URL.OPEN_SUBTITLES, verbose=0, allow_none=True)

    @staticmethod
    def get_languages():
        return [lang_to_iso_3[lang] for lang in settings.get_languages(SETTINGS.SUBTITLES_PROVIDER_PREFERRED_LANGUAGE,
                                                                       SETTINGS.SUBTITLES_PROVIDER_FALLBACK_LANGUAGE)]

    def login(self, username, password):
        response = self.server.LogIn(username, password, 'en', 'XBMC_Subtitles_v1')
        return response

    def search(self, imdb_id, season=None, episode=None):
        username = settings[SETTINGS.SUBTITLES_PROVIDER_USERNAME]
        password = settings[SETTINGS.SUBTITLES_PROVIDER_PASSWORD]
        languages = OpenSubtitles.get_languages()
        token = self.login(username, password)['token']
        result = self.server.SearchSubtitles(token, [{
            'sublanguageid': ','.join(languages),
            'imdbid': imdb_id,
            'season': season,
            'episode': episode
        }])
        for language in languages:
            for data in result.get('data'):
                if data.get('SubLanguageID') == language:
                    return data


OpenSubtitles = OpenSubtitles()
